A gui module for pygame that allows for the creation of buttons, texstboxes, tables, text, sliders and scroll bars inside the pygame module. It acts as an add on to normal pygame code, and can be seamlessly integrated into pre existing code so a simple gui can be added.
PyUI(the real name) was taken.
More Info on My github: https://github.com/LazerWolfeGod/PyUI